boomsheets library

Classes

Anim
Anim represents a single animation state with a name.
Document
Document represents a fully-parsed .anim file.
DocumentReader
DocumentReader reads generated boomsheets anim docs and parses them.
ElementInfo
ElementInfo has the lineNumber which it was parsed from and the result element.
ErrorInfo
ErrorInfo has the offending line and reason message.
Keyframe
A Keyframe represents a rect on a spritesheet.
LabeledPoint
Point
Tickrate
Tickrate provides fractional Frametime values over time via digest.

Enums

Extensions
Optional extensions to support while parsing the document. Extensions:

Extension Types

Attribute
Attribute extension type wraps Element to distinguish them.
Frametime
An extension over int storing the value in count.

Typedefs

KeyframeRect = ({Point<int> pos, Point<int> size})
ParserErrorHandler = void Function(List<ErrorInfo> errors)
ParserErrorHandler receives the errors and line numbers in ErrorInfo.